@@ -55,6 +55,7 @@
         };
     size_t log2ceil( size_t v )
     {
+        if (!IS_LITTLE_ENDIAN) return (size_t)(ceill(log2l((long double) v)));
 
         v--;
         v |= v >> 1; // first round down to one less than a power of 2
@@ -78,6 +79,8 @@
 
     size_t log2ceil(size_t value)
     {
+        if (!IS_LITTLE_ENDIAN) return (size_t)(ceill(log2l((long double) value)));
+        
         value--;
         value |= value >> 1;
         value |= value >> 2;
@@ -1627,7 +1630,7 @@ void get_range(size_t ix_arr[], real_t x[], size_t st, size_t end,
         }
     }
 
-    unsplittable = (xmin == xmax) || (xmin == HUGE_VAL && xmax == -HUGE_VAL);
+    unsplittable = (xmin == xmax) || (xmin == HUGE_VAL && xmax == -HUGE_VAL) || isnan(xmin) || isnan(xmax);
 }
 
 /* for sparse inputs */
@@ -1723,7 +1726,7 @@ void get_range(size_t ix_arr[], size_t st, size_t end, size_t col_num,
         xmin = std::fmin(xmin, 0);
         xmax = std::fmax(xmax, 0);
     }
-    unsplittable = (xmin == xmax) || (xmin == HUGE_VAL && xmax == -HUGE_VAL);
+    unsplittable = (xmin == xmax) || (xmin == HUGE_VAL && xmax == -HUGE_VAL) || isnan(xmin) || isnan(xmax);
 
 }
 
